Epochs
--------

Main
^^^^^^^^^^^^^^^^
*epochs_create()*
"""""""""""""""""""
.. autofunction:: neurokit2.epochs.epochs_create

*epochs_plot()*
"""""""""""""""""
.. autofunction:: neurokit2.epochs.epochs_plot

*epochs_average()*
"""""""""""""""""""
.. autofunction:: neurokit2.epochs.epochs_average

*epochs_to_array()*
""""""""""""""""""""
.. autofunction:: neurokit2.epochs.epochs_to_array

*epochs_to_df()*
""""""""""""""""""""""
.. autofunction:: neurokit2.epochs.epochs_to_df
